@@ -19,6 +19,19 @@ def get_probe_runner_host():
     return "https://proberunner.internal.olympus-world.zetaapps.in"
 
 
+def get_zone(url):
+    if "https://api.tachyon.hdfcbank.com/plutus1/" in url:
+        return "hbl-aws-aps1-zeta-pcidss-1-prod-eks"
+    elif "https://api.tachyon.hdfcbank.com/plutus/" in url:
+        return "hbl-aws-aps1-zeta-nonpcidss-1-prod-eks"
+    elif "https://api.tachyon.uat.hdfcbank.com/gwplutus/" in url:
+        return "hbl-aws-aps1-zeta-pcidss-1-uat-eks"
+    elif "https://api.tachyon.uat.hdfcbank.com/plutus/" in url:
+        return "hbl-aws-aps1-zeta-nonpcidss-1-uat-eks"
+    else:
+        return "aws-hdfc-beta-mumbai"
+
+
 def trace(zone):
     os.environ["SKIP_ADAPTER"] = "True"
     probe_url = get_probe_runner_host() + f"/trace/headers?zone={zone}"
@@ -52,7 +65,7 @@ def logged_request(method, url, **kwargs):
         response = None
         start_time = int(time.time() * 1000)
 
-        zone = os.environ.get("ZONE", None)
+        zone = get_zone(url)
         flow_id = os.environ.get("FLOW_ID", None)
 
         try:
